callback property
User can define a custom callback when the swipe action is completed
Implementation
final FutureOr<void> Function() callback;
User can define a custom callback when the swipe action is completed
final FutureOr<void> Function() callback;